==> tsml-eval-0.1.1.tar.gz: tsml-eval-0.1.1/README.md <==
[![github-actions-release](https://img.shields.io/github/actions/workflow/status/time-series-machine-learning/tsml-eval/release.yml?logo=github&label=build%20%28release%29)](https://github.com/time-series-machine-learning/tsml-eval/actions/workflows/release.yml)
[![github-actions-main](https://img.shields.io/github/actions/workflow/status/time-series-machine-learning/tsml-eval/tests.yml?logo=github&branch=main&label=build%20%28main%29)](https://github.com/time-series-machine-learning/tsml-eval/actions/workflows/tests.yml)
[![docs-release](https://img.shields.io/readthedocs/tsml-eval/stable?logo=readthedocs&label=docs%20%28stable%29)](https://tsml-eval.readthedocs.io/en/stable/)
[![docs-main](https://img.shields.io/readthedocs/tsml-eval/latest?logo=readthedocs&label=docs%20%28latest%29)](https://tsml-eval.readthedocs.io/en/latest/)
[![codecov](https://img.shields.io/codecov/c/github/time-series-machine-learning/tsml-eval?label=codecov&logo=codecov)](https://codecov.io/gh/time-series-machine-learning/tsml-eval)
[![pypi](https://img.shields.io/pypi/v/tsml-eval?logo=pypi&color=blue)](https://pypi.org/project/tsml-eval/)
[![python-versions](https://img.shields.io/pypi/pyversions/tsml-eval?logo=python)](https://www.python.org/)
[![black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![license](https://img.shields.io/badge/license-BSD%203--Clause-green?logo=style)](https://github.com/time-series-machine-learning/tsml-eval/blob/main/LICENSE)

# tsml-eval

tsml-eval contains benchmarking and evaluation tools for time series machine learning
algorithms.

The current release of tsml-eval is v0.1.1.

Installation
------------

tsml-eval is available on PyPI and can be installed via pip:

    pip install tsml-eval

More information available on out documentation webpage:
https://tsml-eval.readthedocs.io/en/stable/

Acknowledgements
----------------

This work is supported by the UK Engineering and Physical Sciences Research Council
(EPSRC) EP/W030756/1

==> tsml-eval-0.2.0.tar.gz: tsml-eval-0.2.0/README.md <==
[![github-actions-release](https://img.shields.io/github/actions/workflow/status/time-series-machine-learning/tsml-eval/release.yml?logo=github&label=build%20%28release%29)](https://github.com/time-series-machine-learning/tsml-eval/actions/workflows/release.yml)
[![github-actions-main](https://img.shields.io/github/actions/workflow/status/time-series-machine-learning/tsml-eval/tests.yml?logo=github&branch=main&label=build%20%28main%29)](https://github.com/time-series-machine-learning/tsml-eval/actions/workflows/tests.yml)
[![docs-release](https://img.shields.io/readthedocs/tsml-eval/stable?logo=readthedocs&label=docs%20%28stable%29)](https://tsml-eval.readthedocs.io/en/stable/)
[![docs-main](https://img.shields.io/readthedocs/tsml-eval/latest?logo=readthedocs&label=docs%20%28latest%29)](https://tsml-eval.readthedocs.io/en/latest/)
[![codecov](https://img.shields.io/codecov/c/github/time-series-machine-learning/tsml-eval?label=codecov&logo=codecov)](https://codecov.io/gh/time-series-machine-learning/tsml-eval)
[![pypi](https://img.shields.io/pypi/v/tsml-eval?logo=pypi&color=blue)](https://pypi.org/project/tsml-eval/)
[![!conda](https://img.shields.io/conda/vn/conda-forge/tsml-eval?logo=anaconda&color=blue)](https://anaconda.org/conda-forge/tsml-eval)
[![python-versions](https://img.shields.io/pypi/pyversions/tsml-eval?logo=python)](https://www.python.org/)
[![black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![license](https://img.shields.io/badge/license-BSD%203--Clause-green?logo=style)](https://github.com/time-series-machine-learning/tsml-eval/blob/main/LICENSE)

# tsml-eval

`tsml-eval` contains benchmarking and evaluation tools for time series machine learning
algorithms.

The current release of `tsml-eval` is v0.2.0.

## Installation

`tsml-eval` is available on PyPI and can be installed via pip:

```console
pip install tsml-eval
```

More information available on our [documentation](https://tsml-eval.readthedocs.io/en/stable/installation.html).

## Acknowledgements

This work is supported by the UK Engineering and Physical Sciences Research Council
(EPSRC) EP/W030756/2
